@@ -38,7 +38,7 @@ struct whitelist_entry {
 
 bool is_whitelisted(char*, bool);
 void cleanup_whitelist();
-void add_to_whitelist(char*, char*, bool);
+void add_to_whitelist(char*, char*, bool, int, const void *);
 
 #ifdef _WHITELIST_INTERNAL
 struct whitelist_entry *root = NULL;
