@@ -1,6 +1,6 @@
 /*
  * mxallowd
- * (c) 2007-2008 Michael Stapelberg
+ * (c) 2007-2009 Michael Stapelberg
  * http://michael.stapelberg.de/mxallowd
  *
  *
@@ -65,7 +65,7 @@
 #include "nfq.h"
 #endif
 
-#define MXALLOWD_VERSION	"1.6a"
+#define MXALLOWD_VERSION	"1.7"
 
 /*
  * Adds a mailserver to the list of fake or real mailservers (configuration)
@@ -277,15 +277,12 @@ int main(int argc, char **argv) {
 #endif
 
 	if (!stay_in_foreground) {
-		slog("Forking into background...\n");
-		pid_t pid = fork();
-		if (pid < 0)
-			diep("fork()");
-		else if (pid > 0)
-			return 0;
+		slog("Daemonizing...\n");
+		if (daemon(0, 0) < 0)
+			slog("Cannot daemonize\n");
 
 		int fd;
-		if ((fd = open("/var/run/mxallowd.pid", O_WRONLY | O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)) < 0)
+		if ((fd = open("/var/run/mxallowd.pid", O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)) < 0)
 			fprintf(stderr, "Error: Could not create /var/run/mxallowd.pid\n");
 		else {
 			char buffer[256];
@@ -322,7 +319,6 @@ int main(int argc, char **argv) {
 #ifdef PF
 	if ((pffd = open("/dev/pf", O_RDWR)) < 0)
 		diep("Couldn't open /dev/pf\n");
-	/* TODO: drop privs */
 	pcap_init();
 #else
 	nfq_init();
